@@ -366,7 +366,7 @@ pg_vidinfo_str(PyObject *self)
 }
 
 static PyTypeObject pgVidInfo_Type = {
-    PyVarObject_HEAD_INIT(NULL, 0).tp_name = "VidInfo",
+    PyVarObject_HEAD_INIT(NULL, 0).tp_name = "pygame.display.VidInfo",
     .tp_basicsize = sizeof(pgVidInfoObject),
     .tp_dealloc = pg_vidinfo_dealloc,
     .tp_getattr = pg_vidinfo_getattr,
@@ -474,12 +474,10 @@ pg_get_wm_info(PyObject *self, PyObject *_null)
     tmp = PyLong_FromLongLong((long long)info.info.win.hdc);
     PyDict_SetItemString(dict, "hdc", tmp);
     Py_DECREF(tmp);
-#if SDL_VERSION_ATLEAST(2, 0, 6)
     tmp = PyLong_FromLongLong((long long)info.info.win.hinstance);
     PyDict_SetItemString(dict, "hinstance", tmp);
     Py_DECREF(tmp);
 #endif
-#endif
 #if defined(SDL_VIDEO_DRIVER_WINRT)
     tmp = PyCapsule_New(info.info.winrt.window, "window", NULL);
     PyDict_SetItemString(dict, "window", tmp);
@@ -542,16 +540,6 @@ pg_get_wm_info(PyObject *self, PyObject *_null)
     PyDict_SetItemString(dict, "shell_surface", tmp);
     Py_DECREF(tmp);
 #endif
-#if defined(SDL_VIDEO_DRIVER_MIR) /* no longer available, left for API/ABI \
-                                     compatibility. Remove in 2.1! */
-    tmp = PyCapsule_New(info.info.mir.connection, "connection", NULL);
-    PyDict_SetItemString(dict, "connection", tmp);
-    Py_DECREF(tmp);
-
-    tmp = PyCapsule_New(info.info.mir.surface, "surface", NULL);
-    PyDict_SetItemString(dict, "surface", tmp);
-    Py_DECREF(tmp);
-#endif
 #if defined(SDL_VIDEO_DRIVER_ANDROID)
     tmp = PyCapsule_New(info.info.android.window, "window", NULL);
     PyDict_SetItemString(dict, "window", tmp);
@@ -706,8 +694,6 @@ pg_ResizeEventWatch(void *userdata, SDL_Event *event)
         return 0;
 
     if (pg_renderer != NULL) {
-#if (SDL_VERSION_ATLEAST(2, 0, 5))
-
         if (event->window.event == SDL_WINDOWEVENT_MAXIMIZED) {
             SDL_RenderSetIntegerScale(pg_renderer, SDL_FALSE);
         }
@@ -716,7 +702,6 @@ pg_ResizeEventWatch(void *userdata, SDL_Event *event)
                 pg_renderer, !(SDL_GetHintBoolean(
                                  "SDL_HINT_RENDER_SCALE_QUALITY", SDL_FALSE)));
         }
-#endif
         return 0;
     }
 
@@ -1039,21 +1024,14 @@ pg_set_mode(PyObject *self, PyObject *arg, PyObject *kwds)
                 SDL_Rect display_bounds;
                 int fractional_scaling = SDL_FALSE;
 
-#if (SDL_VERSION_ATLEAST(2, 0, 5))
                 if (0 !=
                     SDL_GetDisplayUsableBounds(display, &display_bounds)) {
                     return RAISE(pgExc_SDLError, SDL_GetError());
                 }
-#else
-                display_bounds.w = display_mode.w - 80;
-                display_bounds.h = display_mode.h - 30;
-#endif
 
-#if (SDL_VERSION_ATLEAST(2, 0, 5))
                 if (SDL_GetHintBoolean("SDL_HINT_RENDER_SCALE_QUALITY",
                                        SDL_FALSE))
                     fractional_scaling = SDL_TRUE;
-#endif
                 if (state->scaled_gl)
                     fractional_scaling = SDL_TRUE;
 
@@ -1097,7 +1075,16 @@ pg_set_mode(PyObject *self, PyObject *arg, PyObject *kwds)
 
             if (!win) {
                 /*open window*/
-                win = SDL_CreateWindow(title, x, y, w_1, h_1, sdl_flags);
+
+                char *window_id = SDL_getenv("SDL_WINDOWID");
+                if (window_id) {
+                    long long win_long = SDL_strtol(window_id, NULL, 0);
+                    win = SDL_CreateWindowFrom((const void *)win_long);
+                }
+                else {
+                    win = SDL_CreateWindow(title, x, y, w_1, h_1, sdl_flags);
+                }
+
                 if (!win)
                     return RAISE(pgExc_SDLError, SDL_GetError());
             }
@@ -1113,16 +1100,10 @@ pg_set_mode(PyObject *self, PyObject *arg, PyObject *kwds)
                 SDL_SetWindowTitle(win, title);
                 SDL_SetWindowSize(win, w_1, h_1);
 
-#if (SDL_VERSION_ATLEAST(2, 0, 5))
-                SDL_SetWindowResizable(win, flags & PGS_RESIZABLE);
-#endif
-                SDL_SetWindowBordered(win, (flags & PGS_NOFRAME) == 0);
-
-                if ((flags & PGS_SHOWN) || !(flags & PGS_HIDDEN))
-                    SDL_ShowWindow(win);
-                else if (flags & PGS_HIDDEN)
-                    SDL_HideWindow(win);
-
+                /* The window must be brought out of fullscreen before the
+                 * resize/bordered/hidden changes due to SDL ignoring those
+                 * changes if the window is fullscreen
+                 * See https://github.com/pygame/pygame/issues/2711 */
                 if (0 !=
                     SDL_SetWindowFullscreen(
                         win, sdl_flags & (SDL_WINDOW_FULLSCREEN |
@@ -1130,6 +1111,14 @@ pg_set_mode(PyObject *self, PyObject *arg, PyObject *kwds)
                     return RAISE(pgExc_SDLError, SDL_GetError());
                 }
 
+                SDL_SetWindowResizable(win, flags & PGS_RESIZABLE);
+                SDL_SetWindowBordered(win, (flags & PGS_NOFRAME) == 0);
+
+                if ((flags & PGS_SHOWN) || !(flags & PGS_HIDDEN))
+                    SDL_ShowWindow(win);
+                else if (flags & PGS_HIDDEN)
+                    SDL_HideWindow(win);
+
                 SDL_SetWindowPosition(win, x, y);
 
                 assert(surface);
@@ -1168,18 +1157,22 @@ pg_set_mode(PyObject *self, PyObject *arg, PyObject *kwds)
                where the driver lies to us because the user has configured
                vsync to be always on or always off, or vsync is on by default
                for the whole desktop because of wayland GL compositing. */
-            if (vsync) {
+            if (vsync == -1) {
                 if (SDL_GL_SetSwapInterval(-1) != 0) {
                     if (PyErr_WarnEx(PyExc_Warning,
                                      "adaptive vsync for OpenGL not "
-                                     "available, trying regular",
+                                     "available",
                                      1) != 0) {
                         _display_state_cleanup(state);
                         goto DESTROY_WINDOW;
                     }
+                }
+            }
+            else {
+                if (vsync == 1) {
                     if (SDL_GL_SetSwapInterval(1) != 0) {
                         if (PyErr_WarnEx(PyExc_Warning,
-                                         "regular vsync for OpenGL *also* not "
+                                         "regular vsync for OpenGL not "
                                          "available",
                                          1) != 0) {
                             _display_state_cleanup(state);
@@ -1187,9 +1180,9 @@ pg_set_mode(PyObject *self, PyObject *arg, PyObject *kwds)
                         }
                     }
                 }
-            }
-            else {
-                SDL_GL_SetSwapInterval(0);
+                else {
+                    SDL_GL_SetSwapInterval(0);
+                }
             }
         }
         else {
@@ -1218,8 +1211,6 @@ pg_set_mode(PyObject *self, PyObject *arg, PyObject *kwds)
                                      "failed to create renderer");
                     }
 
-#if (SDL_VERSION_ATLEAST(2, 0, 5))
-
                     /* use whole screen with uneven pixels on fullscreen,
                        exact scale otherwise.
                        we chose the window size for this to work */
@@ -1228,7 +1219,6 @@ pg_set_mode(PyObject *self, PyObject *arg, PyObject *kwds)
                         !(flags & PGS_FULLSCREEN ||
                           SDL_GetHintBoolean("SDL_HINT_RENDER_SCALE_QUALITY",
                                              SDL_FALSE)));
-#endif
                     SDL_RenderSetLogicalSize(pg_renderer, w, h);
                     /* this must be called after creating the renderer!*/
                     SDL_SetWindowMinimumSize(win, w, h);
@@ -1803,6 +1793,12 @@ pg_set_palette(PyObject *self, PyObject *args)
 static PyObject *
 pg_set_gamma(PyObject *self, PyObject *arg)
 {
+    if (PyErr_WarnEx(PyExc_DeprecationWarning,
+                     "pygame.display.set_gamma deprecated since 2.2.0",
+                     1) == -1) {
+        return NULL;
+    }
+
     float r, g, b;
     int result = 0;
     _DisplayState *state = DISPLAY_MOD_STATE(self);
@@ -1889,6 +1885,12 @@ pg_convert_to_uint16(PyObject *python_array, Uint16 *c_uint16_array)
 static PyObject *
 pg_set_gamma_ramp(PyObject *self, PyObject *arg)
 {
+    if (PyErr_WarnEx(PyExc_DeprecationWarning,
+                     "pygame.display.set_gamma_ramp deprecated since 2.2.0",
+                     1) == -1) {
+        return NULL;
+    }
+
     _DisplayState *state = DISPLAY_MOD_STATE(self);
     SDL_Window *win = pg_GetDefaultWindow();
     Uint16 *gamma_ramp = (Uint16 *)malloc((3 * 256) * sizeof(Uint16));
@@ -2084,7 +2086,7 @@ pg_toggle_fullscreen(PyObject *self, PyObject *_null)
 {
     SDL_Window *win = pg_GetDefaultWindow();
     int result, flags;
-    int window_w, window_h, w, h, window_display;
+    int window_w, window_h, w, h, window_display, x, y;
     SDL_DisplayMode display_mode;
     pgSurfaceObject *display_surface;
     _DisplayState *state = DISPLAY_MOD_STATE(self);
@@ -2096,8 +2098,7 @@ pg_toggle_fullscreen(PyObject *self, PyObject *_null)
     if (!win)
         return RAISE(pgExc_SDLError, "No open window");
 
-    flags = SDL_GetWindowFlags(win) & SDL_WINDOW_FULLSCREEN_DESKTOP;
-    /* SDL_WINDOW_FULLSCREEN_DESKTOP includes SDL_WINDOW_FULLSCREEN */
+    flags = SDL_GetWindowFlags(win);
 
     SDL_VERSION(&wm_info.version);
     if (!SDL_GetWindowWMInfo(win, &wm_info)) {
@@ -2145,9 +2146,7 @@ pg_toggle_fullscreen(PyObject *self, PyObject *_null)
 
             // Untested and unsupported platforms
         case SDL_SYSWM_MIR:  // nobody uses mir any more, wayland has won
-#if SDL_VERSION_ATLEAST(2, 0, 5)
         case SDL_SYSWM_VIVANTE:
-#endif
         case SDL_SYSWM_UNKNOWN:
         default:
             return RAISE(pgExc_SDLError, "Unsupported platform");
@@ -2157,6 +2156,7 @@ pg_toggle_fullscreen(PyObject *self, PyObject *_null)
 
     // could also take the size of the old display surface
     SDL_GetWindowSize(win, &window_w, &window_h);
+    SDL_GetWindowPosition(win, &x, &y);
     window_display = SDL_GetWindowDisplayIndex(win);
     if (SDL_GetDesktopDisplayMode(window_display, &display_mode) != 0) {
         return RAISE(pgExc_SDLError, SDL_GetError());
@@ -2208,12 +2208,10 @@ pg_toggle_fullscreen(PyObject *self, PyObject *_null)
             }
             SDL_RenderSetLogicalSize(pg_renderer, w, h);
 
-#if (SDL_VERSION_ATLEAST(2, 0, 5))
             /* use exact integer scale in windowed mode */
             SDL_RenderSetIntegerScale(
                 pg_renderer, !SDL_GetHintBoolean(
                                  "SDL_HINT_RENDER_SCALE_QUALITY", SDL_FALSE));
-#endif
             SDL_SetWindowMinimumSize(win, w, h);
         }
         else if (state->using_gl) {
@@ -2273,7 +2271,9 @@ pg_toggle_fullscreen(PyObject *self, PyObject *_null)
                              1) != 0) {
                 return NULL;
             }
-            win = SDL_CreateWindow(state->title, wx, wy, w, h, 0);
+            flags &= ~SDL_WINDOW_FULLSCREEN_DESKTOP;
+            /* SDL_WINDOW_FULLSCREEN_DESKTOP includes SDL_WINDOW_FULLSCREEN */
+            win = SDL_CreateWindow(state->title, wx, wy, w, h, flags);
             if (win == NULL) {
                 return RAISE(pgExc_SDLError, SDL_GetError());
             }
@@ -2292,12 +2292,31 @@ pg_toggle_fullscreen(PyObject *self, PyObject *_null)
         }
         state->toggle_windowed_w = 0;
         state->toggle_windowed_h = 0;
+
+        x = state->fullscreen_backup_x;
+        y = state->fullscreen_backup_y;
+
+        // if the program goes into fullscreen first the "saved
+        // x and y" are "undefined position" that should be
+        // interpreted as a cue to center the window
+        if (x == (int)SDL_WINDOWPOS_UNDEFINED_DISPLAY(window_display))
+            x = SDL_WINDOWPOS_CENTERED_DISPLAY(window_display);
+        if (y == (int)SDL_WINDOWPOS_UNDEFINED_DISPLAY(window_display))
+            y = SDL_WINDOWPOS_CENTERED_DISPLAY(window_display);
+
+#if (SDL_VERSION_ATLEAST(2, 0, 5))
+        SDL_SetWindowResizable(win, flags & SDL_WINDOW_RESIZABLE);
+#endif
+        SDL_SetWindowBordered(win, (flags & SDL_WINDOW_BORDERLESS) == 0);
+
+        SDL_SetWindowPosition(win, x, y);
     }
     else {
         /* TOGGLE FULLSCREEN ON */
-
         state->toggle_windowed_w = w;
         state->toggle_windowed_h = h;
+        state->fullscreen_backup_x = x;
+        state->fullscreen_backup_y = y;
         if (pg_renderer != NULL) {
             result =
                 SDL_SetWindowFullscreen(win, SDL_WINDOW_FULLSCREEN_DESKTOP);
@@ -2323,9 +2342,7 @@ pg_toggle_fullscreen(PyObject *self, PyObject *_null)
             }
 
             SDL_RenderSetLogicalSize(pg_renderer, w, h);
-#if (SDL_VERSION_ATLEAST(2, 0, 5))
             SDL_RenderSetIntegerScale(pg_renderer, SDL_FALSE);
-#endif
         }
         else if (state->using_gl) {
             result =
@@ -2380,10 +2397,13 @@ pg_toggle_fullscreen(PyObject *self, PyObject *_null)
                 h != display_surface->surf->h) {
                 int wx = SDL_WINDOWPOS_UNDEFINED_DISPLAY(window_display);
                 int wy = SDL_WINDOWPOS_UNDEFINED_DISPLAY(window_display);
-                win = SDL_CreateWindow(state->title, wx, wy, w, h, 0);
+                win = SDL_CreateWindow(state->title, wx, wy, w, h, flags);
                 if (win == NULL) {
                     return RAISE(pgExc_SDLError, SDL_GetError());
                 }
+                if (0 != SDL_SetWindowFullscreen(win, SDL_WINDOW_FULLSCREEN)) {
+                    return RAISE(pgExc_SDLError, SDL_GetError());
+                }
                 display_surface->surf = SDL_GetWindowSurface(win);
                 pg_SetDefaultWindow(win);
                 if (PyErr_WarnEx(PyExc_Warning,
