@@ -34,6 +34,13 @@
 
 #include <limits.h>
 
+#if (!defined(__STDC_VERSION__) || __STDC_VERSION__ < 199901L) && \
+    !defined(round)
+#define pg_round(d) (((d < 0) ? (ceil((d)-0.5)) : (floor((d) + 0.5))))
+#else
+#define pg_round(d) round(d)
+#endif
+
 static PyTypeObject pgRect_Type;
 #define pgRect_Check(x) (PyObject_IsInstance(x, (PyObject *)&pgRect_Type))
 #define pgRect_CheckExact(x) (Py_TYPE(x) == &pgRect_Type)
@@ -427,6 +434,38 @@ pg_rect_inflate_ip(pgRectObject *self, PyObject *args)
     Py_RETURN_NONE;
 }
 
+static PyObject *
+pg_rect_scale_by_ip(pgRectObject *self, PyObject *args)
+{
+    float factor_x, factor_y = 0;
+
+    if (!PyArg_ParseTuple(args, "f|f", &factor_x, &factor_y)) {
+        return NULL;
+    }
+
+    factor_x = factor_x < 0 ? -factor_x : factor_x;
+    factor_y = factor_y < 0 ? -factor_y : factor_y;
+
+    factor_y = (factor_y > 0) ? factor_y : factor_x;
+
+    self->r.x =
+        (int)(self->r.x + (self->r.w / 2) - (self->r.w * factor_x / 2));
+    self->r.y =
+        (int)(self->r.y + (self->r.h / 2) - (self->r.h * factor_y / 2));
+    self->r.w = (int)(self->r.w * factor_x);
+    self->r.h = (int)(self->r.h * factor_y);
+    Py_RETURN_NONE;
+}
+
+static PyObject *
+pg_rect_scale_by(pgRectObject *self, PyObject *args)
+{
+    pgRectObject *returnRect = (pgRectObject *)_pg_rect_subtype_new4(
+        Py_TYPE(self), self->r.x, self->r.y, self->r.w, self->r.h);
+    pg_rect_scale_by_ip(returnRect, args);
+    return (PyObject *)returnRect;
+}
+
 static PyObject *
 pg_rect_update(pgRectObject *self, PyObject *args)
 {
@@ -1351,6 +1390,7 @@ static struct PyMethodDef pg_rect_methods[] = {
     {"fit", (PyCFunction)pg_rect_fit, METH_VARARGS, DOC_RECTFIT},
     {"move", (PyCFunction)pg_rect_move, METH_VARARGS, DOC_RECTMOVE},
     {"update", (PyCFunction)pg_rect_update, METH_VARARGS, DOC_RECTUPDATE},
+    {"scale_by", (PyCFunction)pg_rect_scale_by, METH_VARARGS, DOC_RECTSCALEBY},
     {"inflate", (PyCFunction)pg_rect_inflate, METH_VARARGS, DOC_RECTINFLATE},
     {"union", (PyCFunction)pg_rect_union, METH_VARARGS, DOC_RECTUNION},
     {"unionall", (PyCFunction)pg_rect_unionall, METH_VARARGS,
@@ -1358,6 +1398,8 @@ static struct PyMethodDef pg_rect_methods[] = {
     {"move_ip", (PyCFunction)pg_rect_move_ip, METH_VARARGS, DOC_RECTMOVEIP},
     {"inflate_ip", (PyCFunction)pg_rect_inflate_ip, METH_VARARGS,
      DOC_RECTINFLATEIP},
+    {"scale_by_ip", (PyCFunction)pg_rect_scale_by_ip, METH_VARARGS,
+     DOC_RECTSCALEBYIP},
     {"union_ip", (PyCFunction)pg_rect_union_ip, METH_VARARGS, DOC_RECTUNIONIP},
     {"unionall_ip", (PyCFunction)pg_rect_unionall_ip, METH_VARARGS,
      DOC_RECTUNIONALLIP},
@@ -1716,6 +1758,52 @@ pg_rect_iterator(pgRectObject *self)
     return iter;
 }
 
+static int
+_rounded_int_from_object(PyObject *value, int *val)
+{
+    double tmpVal;
+
+    if (!pg_DoubleFromObj(value, &tmpVal)) {
+        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+        return 0;
+    }
+
+    if (tmpVal > INT_MAX || tmpVal < INT_MIN) {
+        PyErr_Format(
+            PyExc_TypeError,
+            "invalid rect assignment, expected value between %d < x < %d",
+            INT_MIN, INT_MAX);
+        return 0;
+    }
+
+    *val = (int)pg_round(tmpVal);
+    return 1;
+}
+
+static int
+_rounded_two_ints_from_object(PyObject *value, int *val1, int *val2)
+{
+    double tmpVal1, tmpVal2;
+
+    if (!pg_TwoDoublesFromObj(value, &tmpVal1, &tmpVal2)) {
+        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+        return 0;
+    }
+
+    if (tmpVal1 > INT_MAX || tmpVal1 < INT_MIN || tmpVal2 > INT_MAX ||
+        tmpVal2 < INT_MIN) {
+        PyErr_Format(
+            PyExc_TypeError,
+            "invalid rect assignment, expected value between %d < x < %d",
+            INT_MIN, INT_MAX);
+        return 0;
+    }
+
+    *val1 = (int)pg_round(tmpVal1);
+    *val2 = (int)pg_round(tmpVal2);
+    return 1;
+}
+
 /*width*/
 static PyObject *
 pg_rect_getwidth(pgRectObject *self, void *closure)
@@ -1734,8 +1822,7 @@ pg_rect_setwidth(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_IntFromObj(value, &val1)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_int_from_object(value, &val1)) {
         return -1;
     }
     self->r.w = val1;
@@ -1760,8 +1847,7 @@ pg_rect_setheight(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_IntFromObj(value, &val1)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_int_from_object(value, &val1)) {
         return -1;
     }
     self->r.h = val1;
@@ -1786,8 +1872,7 @@ pg_rect_settop(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_IntFromObj(value, &val1)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_int_from_object(value, &val1)) {
         return -1;
     }
     self->r.y = val1;
@@ -1812,8 +1897,7 @@ pg_rect_setleft(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_IntFromObj(value, &val1)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_int_from_object(value, &val1)) {
         return -1;
     }
     self->r.x = val1;
@@ -1838,8 +1922,7 @@ pg_rect_setright(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_IntFromObj(value, &val1)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_int_from_object(value, &val1)) {
         return -1;
     }
     self->r.x = val1 - self->r.w;
@@ -1864,8 +1947,7 @@ pg_rect_setbottom(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_IntFromObj(value, &val1)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_int_from_object(value, &val1)) {
         return -1;
     }
     self->r.y = val1 - self->r.h;
@@ -1890,8 +1972,7 @@ pg_rect_setcenterx(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_IntFromObj(value, &val1)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_int_from_object(value, &val1)) {
         return -1;
     }
     self->r.x = val1 - (self->r.w >> 1);
@@ -1916,8 +1997,7 @@ pg_rect_setcentery(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_IntFromObj(value, &val1)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_int_from_object(value, &val1)) {
         return -1;
     }
     self->r.y = val1 - (self->r.h >> 1);
@@ -1942,8 +2022,7 @@ pg_rect_settopleft(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_TwoIntsFromObj(value, &val1, &val2)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_two_ints_from_object(value, &val1, &val2)) {
         return -1;
     }
     self->r.x = val1;
@@ -1969,8 +2048,7 @@ pg_rect_settopright(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_TwoIntsFromObj(value, &val1, &val2)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_two_ints_from_object(value, &val1, &val2)) {
         return -1;
     }
     self->r.x = val1 - self->r.w;
@@ -1996,8 +2074,7 @@ pg_rect_setbottomleft(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_TwoIntsFromObj(value, &val1, &val2)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_two_ints_from_object(value, &val1, &val2)) {
         return -1;
     }
     self->r.x = val1;
@@ -2024,8 +2101,7 @@ pg_rect_setbottomright(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_TwoIntsFromObj(value, &val1, &val2)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_two_ints_from_object(value, &val1, &val2)) {
         return -1;
     }
     self->r.x = val1 - self->r.w;
@@ -2052,8 +2128,7 @@ pg_rect_setmidtop(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_TwoIntsFromObj(value, &val1, &val2)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_two_ints_from_object(value, &val1, &val2)) {
         return -1;
     }
     self->r.x += val1 - (self->r.x + (self->r.w >> 1));
@@ -2080,8 +2155,7 @@ pg_rect_setmidleft(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_TwoIntsFromObj(value, &val1, &val2)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_two_ints_from_object(value, &val1, &val2)) {
         return -1;
     }
     self->r.x = val1;
@@ -2108,8 +2182,7 @@ pg_rect_setmidbottom(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_TwoIntsFromObj(value, &val1, &val2)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_two_ints_from_object(value, &val1, &val2)) {
         return -1;
     }
     self->r.x += val1 - (self->r.x + (self->r.w >> 1));
@@ -2136,8 +2209,7 @@ pg_rect_setmidright(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_TwoIntsFromObj(value, &val1, &val2)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_two_ints_from_object(value, &val1, &val2)) {
         return -1;
     }
     self->r.x = val1 - self->r.w;
@@ -2164,8 +2236,7 @@ pg_rect_setcenter(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_TwoIntsFromObj(value, &val1, &val2)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_two_ints_from_object(value, &val1, &val2)) {
         return -1;
     }
     self->r.x += val1 - (self->r.x + (self->r.w >> 1));
@@ -2191,8 +2262,7 @@ pg_rect_setsize(pgRectObject *self, PyObject *value, void *closure)
         return -1;
     }
 
-    if (!pg_TwoIntsFromObj(value, &val1, &val2)) {
-        PyErr_SetString(PyExc_TypeError, "invalid rect assignment");
+    if (!_rounded_two_ints_from_object(value, &val1, &val2)) {
         return -1;
     }
     self->r.w = val1;
